package com.gic.cloud.data.hook.service.deal.queryfilter;

import com.gic.api.base.commons.Page;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.cloud.data.hook.api.dto.FilterQueryDataDTO;
import com.gic.cloud.data.hook.api.enums.QueryFilterCodeEnum;
import com.gic.cloud.data.hook.service.deal.BaseQueryFilter;
import com.gic.cloud.data.hook.service.deal.QueryFilterContext;
import com.gic.cloud.data.hook.service.entity.QueryFilterInfo;
import com.gic.member.api.dto.GradeBaseDTO;
import com.gic.member.api.service.GradeService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class MemberGradeNameQueryFilter implements BaseQueryFilter {

    @Autowired
    private GradeService gradeService;

    @Override
    public boolean checkFilter(QueryFilterContext context) {
        QueryFilterInfo queryFilterInfo = context.getQueryFilterInfo();
        if (null == queryFilterInfo||queryFilterInfo.getFilterCode()==null) {
            return false;
        }
        return queryFilterInfo.getFilterCode().equals(QueryFilterCodeEnum.GRADE.getCode());
    }

    @Override
    public Page<FilterQueryDataDTO> pageQueryData(QueryFilterContext context) {
        List<GradeBaseDTO> gradeDTOList = gradeService.getGradeDTOList(context.getEnterpriseId());

        Page<FilterQueryDataDTO> ret =new Page<>();
        ret.setPageSize(context.getPageSize());
        ret.setCurrentPage(context.getPageNum());
        ret.setTotalCount(gradeDTOList.size());

        List<FilterQueryDataDTO> retList = gradeDTOList.stream().map(mid -> {
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(mid.getGradeName());
            filterQueryDataDTO.setItemValue(mid.getGradeName());
            filterQueryDataDTO.setSubShowName(mid.getGradeCode());
            return filterQueryDataDTO;
        }).collect(Collectors.toList());
        ret.setResult(retList);
        return ret;
    }

    @Override
    public List<FilterQueryDataDTO> listBackByItems(QueryFilterContext context) {
        List<GradeBaseDTO> gradeDTOList = gradeService.getGradeDTOList(context.getEnterpriseId());
        if (CollectionUtils.isEmpty(gradeDTOList)) {
            return null;
        }
        List<FilterQueryDataDTO> retList = gradeDTOList.stream().map(mid -> {
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(mid.getGradeName());
            filterQueryDataDTO.setItemValue(mid.getGradeName());
            filterQueryDataDTO.setSubShowName(mid.getGradeCode());
            return filterQueryDataDTO;
        }).collect(Collectors.toList());
        return retList;
    }
}
